@@ -7,8 +7,9 @@ let global = {
 }
 
 function save_request(request_id, request) {
+    request.loaded = false;
+    request.to_refresh = true;
     global.requests[request_id] = request;
-    global.requests[request_id].to_refresh = true;
     switch (global.requests[request_id].status_code) {
         case 0:
             global.requests[request_id].status_code_view = "&#9203";
@@ -26,7 +27,18 @@ function save_request(request_id, request) {
 
 async function get_all_requests() {
 
-    await fetch("/requests")
+    var requests_already_loaded = 0
+    for (const [request_id, request] of Object.entries(global.requests)) {
+        if (request.loaded) {
+            requests_already_loaded += 1;
+        }
+    }
+    var url = "/requests?" + new URLSearchParams({
+        "id": global.k7,
+        "requests_already_loaded": requests_already_loaded,
+    })
+
+    await fetch(url)
         .then(res => res.json())
         .then(data => {
             global.connected = true;
@@ -62,6 +74,8 @@ async function get_request(request_id) {
             global.connected = true;
 
             global.requests[request_id]["data"] = data;
+
+            global.requests[request_id].loaded = true;
         })
         .catch((error) => {
             global.connected = false;
